# 爬虫名注册以及配置 配置优先度高于custom_settings 仅配置中间件和管道 该文件未配置的取custom_settings
zhizhong={
    # "pyppeteer_demo.crawl":["zz_rohmcrawl",("spider_middlewares"),("downloader_middlewares"),("pipelines"),("extensions")],
    # "pyppeteer_demo.crawl":["zz_rohmcrawl",("stickyitem"),("ua","proxy","pyppeteer"),("file","file_bak","img","img_bak","bloom","mysql","mongo","rabbit","fctexcel","dpfexcel","kafka"),("closespider"，"mailer")],
    }

yongjie={

    }

xuqi={

    }

juncheng={

    }

yonghao={

    }

siming={

    }

fengchao={

    }

runtao={

    }

yijia={

    }

